@@ -260,6 +260,10 @@ def _file_reduce(obj):
     return _file_reconstructor, (retval,)
 
 
+def _getset_descriptor_reduce(obj):
+    return getattr, (obj.__objclass__, obj.__name__)
+
+
 def _mappingproxy_reduce(obj):
     return types.MappingProxyType, (dict(obj),)
 
@@ -405,6 +409,7 @@ class CloudPickler(Pickler):
     dispatch[staticmethod] = _classmethod_reduce
     dispatch[types.CellType] = _cell_reduce
     dispatch[types.CodeType] = _code_reduce
+    dispatch[types.GetSetDescriptorType] = _getset_descriptor_reduce
     dispatch[types.ModuleType] = _module_reduce
     dispatch[types.MethodType] = _method_reduce
     dispatch[types.MappingProxyType] = _mappingproxy_reduce
